#!/bin/sh
# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-H88, (C) COPYRIGHT International Business Machines Corp., 2004,2006
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

LC_ALL=C
export LC_ALL

PATH=/usr/xpg4/bin:$PATH

# LBBASE gets replaced during packaging
LBBASE=/opt/ibm/edge/ulb

#set some OS defaults
OS=`uname -s`

# Determine appropriate ARCH (only used when executing within a build tree)
if [ -z "$ARCH" ]
then
  case $OS in
  Linux)
    ARCH=`uname -m | sed -e "s/i.86/x86/" -e "s/athlon/x86/" -e "s/^sun.*/sparc/" `
    ;;
  HP-UX)
    ARCH=`uname -m`
    if [ "$ARCH" != "ia64" ]; then
      ARCH=parisc
    fi
    ;;
  AIX)
    if [ `bootinfo -K` = "64" ]; then
      ARCH=ppc64
    else
      ARCH=ppc
    fi
    ;;
  SunOS)
    # Note that by default, we get 32-bit sparc, not 64-bit sparcv9
    ARCH=`uname -p | sed -e "s/i.86/x86_64/" -e "s/^sun.*/sparc/"`
    ;;
  *)
    echo unrecognized OS $OS
    exit 1
    ;;
  esac
fi

# Determine appropriate COMPILER (only used when executing within a build tree)
if [ -z "$COMPILER" ]
then
  case $OS in
  Linux)
    COMPILER=gcc32
    ;;
  HP-UX)
    COMPILER=gcc40
    ;;
  AIX)
    COMPILER=xlc80
    ;;
  SunOS)
    #Need to set up the correct gcc version for running in the build tree
    if [ "$ARCH" = "x86_64" ]; then
       COMPILER=gcc34
    else
       COMPILER=gcc32
    fi
    ;;
  *)
    echo unrecognized OS $OS
    exit 1
    ;;
  esac
fi

# find java

# see if we're using relative, absolute, or PATH to find our invocation script
if [ `echo $0 | cut -c1` = "/" ]; then
  # invoked with absolute path
  THISDIR=`dirname $0`
  echo absolute path, $THISDIR
elif echo $0 | grep / >/dev/null ; then
  # relative path
  THISDIR=$PWD/`dirname $0 | sed -e "s;^\./;/;g" -e "s;^\.;;g"`
  echo relative path, $THISDIR
else
  # figure out our dir from the path
  DIR=`which $0`
  THISDIR=`dirname $DIR`
  echo on path, $THISDIR
fi

if [ -z "$THISDIR" -o ! -d "$THISDIR" ]
then
  echo Could not calculate topdir
  exit 1
fi

#echo Using LB in $THISDIR
for JAVA in $LBBASE/java/jre/bin/java            \
	    $JAVAHOME/jre/bin/java               \
	    `which java`                      
do
  if [ -x $JAVA ]
  then
    echo java is $JAVA
    break;
  fi
done

if [ ! -x $JAVA ]
then
  echo No JAVA!
  exit 1
fi

# Ensure we throw -d64 on appropriate platforms
case $OS-$ARCH in
  *-ppc64)
    LB_64BIT=-d64
    ;;
  *-ia64)
    LB_64BIT=-d64
    ;;
  *-x86_64)
    LB_64BIT=-d64
    ;;
  *-s390x)
    LB_64BIT=-d64
    ;;
  *-sparcv9)
    LB_64BIT=-d64
    ;;
  *)
    LB_64BIT=
    ;;
esac


# see if we're running out of a build tree
if [ -d $THISDIR/../bin/config/$OS/$ARCH/$COMPILER -a -f $THISDIR/../bin/config/ibmlb2.jar ];
 then
  echo Running out of a build tree
  JAVALIBDIR=$THISDIR/../bin/config/$OS/$ARCH/$COMPILER
  JAR=$THISDIR/../bin/config/ibmlb2.jar
  LBSCRIPTDIR=$THISDIR
elif [ -x $LBBASE/servers/bin/ibmlb2 -a -f $LBBASE/servers/lib/ibmlb2.jar ];
  then
   JAVALIBDIR=$LBBASE/servers/lib
   JAR=$JAVALIBDIR/ibmlb2.jar
   LBSCRIPTDIR=$LBBASE/servers/bin
else
  echo error, could not locate needed components
  exit 1
fi

if [ ! -f $JAR ] ; then
  echo Failed to find $JAR
  exit 1
fi
if [ ! -d $JAVALIBDIR ] ; then
  echo failed to find dir $JAVALIBDIR
  exit 1
fi

#echo lib=$JAVALIBDIR jar=$JAR

echo $JAVA $LB_64BIT -Djava.library.path=$JAVALIBDIR -Dcom.ibm.ws.loadbalancer.scripts=${LBSCRIPTDIR} -cp $JAR com.ibm.ws.loadbalancer.stack.LBStackCmdBuf $*                   
$JAVA $LB_64BIT -Djava.library.path=$JAVALIBDIR -Dcom.ibm.ws.loadbalancer.scripts=${LBSCRIPTDIR} -cp $JAR com.ibm.ws.loadbalancer.stack.LBStackCmdBuf $* 

